(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17221,        423]*)
(*NotebookOutlinePosition[     17863,        445]*)
(*  CellTagsIndexPosition[     17819,        441]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Discrete and Continous Simulation", "Section"],

Cell[BoxData[
    \(<< Graphics`PlotField`\)], "Input"],

Cell[CellGroupData[{

Cell["The System", "Subsubsection"],

Cell["Here, we find any fixed points:", "Text"],

Cell[BoxData[{
    \(\(f1[x_, y_] = y^2 - 1\  - \ x;\)\), "\[IndentingNewLine]", 
    \(\(f2[x_, y_] = x^2 - 1\  - \ y;\)\), "\[IndentingNewLine]", 
    \(\(Solve[{f1[x, y] \[Equal] 0, f2[x, y] \[Equal] 0}, {x, 
          y}];\)\), "\[IndentingNewLine]", 
    \(N[%]\)}], "Input"],

Cell[TextData[{
  "And plot the vector field, from which it looks like the ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, \(-1\))\)\)]],
  " is a stable point:"
}], "Text"],

Cell[BoxData[
    \(field = 
      PlotVectorField[{f1[x, y], f2[x, y]}, {x, \(-0.5\), 
          0.5}, {y, \(-1.25\), \(-0.75\)}, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}, 
        AspectRatio \[Rule] 1]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Discrete Model", "Subsubsection"],

Cell["\<\
We can iterate to get a sequence of points in the phase space:\
\>", "Text"],

Cell[BoxData[{
    \(Clear[x1, x2]\), "\n", 
    \(x1[0] := \ \[Alpha]1\), "\n", 
    \(x2[0] := \ \[Alpha]2\), "\n", 
    \(x1[n_] := \ \(x1[n]\  = \ 
        f1[x1[n - 1], x2[n - 1]] + x1[n - 1]\)\), "\n", 
    \(x2[n_] := \ \(x2[n]\  = \ 
        f2[x1[n - 1], x2[n - 1]] + x2[n - 1]\)\), "\n", 
    \(\(num\  = \ 10;\)\), "\n", 
    \(\(data\  = \ Table[{n, x1[n], x2[n]}, {n, 0, num}];\)\), "\n", 
    \(data\  = \ \(data\  /. \ \[Alpha]1 \[Rule] 
            0.5\)\  /. \[Alpha]2 \[Rule] \(-1.0\)\), "\n", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax1\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 2]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax2\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(ListPlot[phase, PlotJoined \[Rule] True, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}]\), "\[IndentingNewLine]", 
    \(ListPlot[datax1, PlotJoined \[Rule] True, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<n\>", "\<x1\>"}]\), "\[IndentingNewLine]", 
    \(ListPlot[datax2, PlotJoined \[Rule] True, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<n\>", "\<x2\>"}]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Continuous Model", "Subsubsection"],

Cell[BoxData[{
    \(Clear[x1, x2]\), "\n", 
    \(x1[0] := \ \[Alpha]1\), "\n", 
    \(x2[0] := \ \[Alpha]2\), "\n", 
    \(\(num = 10;\)\), "\[IndentingNewLine]", 
    \(\(to\  = \ 0;\)\), "\[IndentingNewLine]", 
    \(\(tf\  = \ 10;\)\), "\[IndentingNewLine]", 
    \(h\  = \ N[\((tf - to)\)/num]\), "\[IndentingNewLine]", 
    \(x1[n_] := \ \(x1[n]\  = \ 
        h\ f1[x1[n - 1], x2[n - 1]] + x1[n - 1]\)\), "\n", 
    \(x2[n_] := \ \(x2[n]\  = \ 
        h\ f2[x1[n - 1], x2[n - 1]] + x2[n - 1]\)\), "\n", 
    \(\(data\  = \ Table[{h*n, x1[n], x2[n]}, {n, 0, num}];\)\), "\n", 
    \(data\  = \ \(data\  /. \ \[Alpha]1 \[Rule] 
            0.5\)\  /. \[Alpha]2 \[Rule] \(-1.0\)\), "\n", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax1\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 2]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax2\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(discretephase = 
      ListPlot[phase, PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}]\), "\[IndentingNewLine]", 
    \(ListPlot[datax1, PlotJoined \[Rule] True, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<n\>", "\<x1\>"}]\), "\[IndentingNewLine]", 
    \(ListPlot[datax2, PlotJoined \[Rule] True, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<n\>", "\<x2\>"}]\)}], "Input"],

Cell[BoxData[{
    \(Clear[x1, x2]\), "\n", 
    \(x1[0] := \ 0.5\), "\n", 
    \(x2[0] := \ \(-1.0\)\), "\n", 
    \(\(num = 500;\)\), "\[IndentingNewLine]", 
    \(\(to\  = \ 0;\)\), "\[IndentingNewLine]", 
    \(\(tf\  = \ 10;\)\), "\[IndentingNewLine]", 
    \(h\  = \ N[\((tf - to)\)/num]\), "\[IndentingNewLine]", 
    \(x1[n_] := \ \(x1[n]\  = \ 
        h\ f1[x1[n - 1], x2[n - 1]] + x1[n - 1]\)\), "\n", 
    \(x2[n_] := \ \(x2[n]\  = \ 
        h\ f2[x1[n - 1], x2[n - 1]] + x2[n - 1]\)\), "\n", 
    \(\(data\  = \ Table[{h*n, x1[n], x2[n]}, {n, 0, num}];\)\), "\n", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax1\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 2]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax2\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(contphase = 
      ListPlot[phase, PlotRange \[Rule] All, PlotJoined \[Rule] True, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}]\), "\[IndentingNewLine]", 
    \(ListPlot[datax1, PlotRange \[Rule] All, PlotJoined \[Rule] True, 
      Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Time, t\>", "\<x1\>"}]\), "\[IndentingNewLine]", \

    \(ListPlot[datax2, PlotRange \[Rule] All, PlotJoined \[Rule] True, 
      Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Time, t\>", "\<x2\>"}]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation of the Discrete to the Continuous", "Subsubsection"],

Cell["\<\
I have set things up so that num=10 corresponds to the discrete case. Higher \
values of num will approach the continuous case.\
\>", "Text"],

Cell[BoxData[
    \(Do[{\[IndentingNewLine]Clear[x1, x2], \[IndentingNewLine]x1[0] := \ 
          0.5, \[IndentingNewLine]x2[
            0] := \ \(-1.0\), \[IndentingNewLine]\[IndentingNewLine]x1[
            n_] := \ \(x1[n]\  = \ h\ f1[x1[n - 1], x2[n - 1]] + x1[n - 1]\), 
        x2[n_] := \ \(x2[n]\  = \ 
            h\ f2[x1[n - 1], x2[n - 1]] + 
              x2[n - 1]\), \n\[IndentingNewLine]num = 
          i, \[IndentingNewLine]to\  = \ 0, \[IndentingNewLine]tf\  = \ 
          10, \[IndentingNewLine]h\  = \ 
          N[\((tf - to)\)/num], \[IndentingNewLine]data\  = \ 
          Table[{h*n, x1[n], x2[n]}, {n, 0, 
              num}], \[IndentingNewLine]dataphase\  = \ 
          Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
              num}], \[IndentingNewLine]ListPlot[dataphase, 
          PlotRange \[Rule] {{\(-0.5\), 0.5}, {\(-1\), \(-0.75\)}}, 
          PlotJoined \[Rule] True, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time, t\>", "\<x1\>"}]}, {i, 10, 15, 
        1}]\)], "Input"],

Cell[BoxData[
    \(Do[{\[IndentingNewLine]Clear[x1, x2], \[IndentingNewLine]x1[0] := \ 
          0.5, \[IndentingNewLine]x2[
            0] := \ \(-1.0\), \[IndentingNewLine]\[IndentingNewLine]x1[
            n_] := \ \(x1[n]\  = \ h\ f1[x1[n - 1], x2[n - 1]] + x1[n - 1]\), 
        x2[n_] := \ \(x2[n]\  = \ 
            h\ f2[x1[n - 1], x2[n - 1]] + 
              x2[n - 1]\), \n\[IndentingNewLine]num = 
          i, \[IndentingNewLine]to\  = \ 0, \[IndentingNewLine]tf\  = \ 
          10, \[IndentingNewLine]h\  = \ 
          N[\((tf - to)\)/num], \[IndentingNewLine]data\  = \ 
          Table[{h*n, x1[n], x2[n]}, {n, 0, 
              num}], \[IndentingNewLine]dataphase\  = \ 
          Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
              num}], \[IndentingNewLine]ListPlot[dataphase, 
          PlotRange \[Rule] {{\(-0.5\), 0.5}, {\(-1\), \(-0.75\)}}, 
          PlotJoined \[Rule] True, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time, t\>", "\<x1\>"}]}, {i, 10, 100, 
        5}]\)], "Input"],

Cell[BoxData[
    \(Show[contphase, discretephase, field, AspectRatio \[Rule] 1]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["An Animated Vector Field", "Subsubsection"],

Cell["\<\
Let's examine how the solutoin changes when we vary the parameter a:\
\>", "Text"],

Cell[BoxData[{
    \(\(f1[x_, y_] = y^2 - 1\  - \ x;\)\), "\[IndentingNewLine]", 
    \(\(f2[x_, y_, a_] = a*x^2 - 1\  - \ y;\)\), "\[IndentingNewLine]", 
    \(Solve[{f1[x, y] \[Equal] 0, f2[x, y] \[Equal] 0}, {x, y}]\)}], "Input"],

Cell["The fixed points are still the same, and do not depend on a.", "Text"],

Cell[BoxData[{
    \(\(fp1\  = \ 
        Graphics[Disk[{\(-1\), 0}, 0.05]];\)\), "\[IndentingNewLine]", 
    \(\(fp2\  = \ 
        Graphics[Disk[{0, \(-1\)}, 0.05]];\)\), "\[IndentingNewLine]", 
    \(\(fp3\  = \ 
        Graphics[
          Disk[{1\/2 - \@5\/2, 1\/2 - \@5\/2}, 
            0.05]];\)\), "\[IndentingNewLine]", 
    \(\(fp4\  = \ 
        Graphics[Disk[{1\/2 + \@5\/2, 1\/2 + \@5\/2}, 0.05]];\)\)}], "Input"],

Cell[BoxData[{
    \(step\  = \ 0.2\), "\[IndentingNewLine]", 
    \(Clear[field]\), "\[IndentingNewLine]", 
    \(\(Table[
        field[i_]\  = \ 
          Show[PlotVectorField[{f1[x, y], f2[x, y, i]}, {x, \(-3\), 
                3}, {y, \(-3\), 3}, 
              PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}}, 
              Frame \[Rule] True, FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}, 
              AspectRatio \[Rule] 1], fp1, fp2, fp3, fp4], {i, 0, 4, 
          step}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 6.5.1", "Subsubsection"],

Cell["\<\
We have added weather conditions to the battle simulation, with weather only \
affecting the effectiveness of direct fire on both sides. w=0 corresponds to \
horrible weather, w=1 corresponds to good weather. In good weather, Red will \
win after 120 hours with 3.00 divisions remaining. Will bad weather improve \
the performance of Blue? \
\>", "Text"],

Cell[BoxData[{
    \(\[Lambda]\  = \ 3\), "\[IndentingNewLine]", 
    \(w\  = \ 1\), "\[IndentingNewLine]", 
    \(\(f1[x_, 
          y_] = \(-w\)\ \[Lambda] \((0.05)\)\ y\  - \[Lambda]\ \((0.005)\)\ x\
\ y;\)\), "\[IndentingNewLine]", 
    \(\(f2[x_, y_] = \(-w\)\ 0.05  x\  - \ 
          0.005  x\ y;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Clear[x1, x2]\), "\n", 
    \(\(x1[0] := \ 5;\)\), "\n", 
    \(\(x2[0] := \ 2;\)\), "\n", 
    \(\(num = 20;\)\), "\n", 
    \(x1[n_] := \ \(x1[n]\  = \ \ f1[x1[n - 1], x2[n - 1]] + 
          x1[n - 1]\)\), "\n", 
    \(x2[n_] := \ \(x2[n]\  = \ \ f2[x1[n - 1], x2[n - 1]] + 
          x2[n - 1]\)\), "\n", 
    \(\(data\  = \ Table[{12*n, x1[n], x2[n]}, {n, 0, num}];\)\), "\n", 
    \(TableForm[data, 
      TableHeadings \[Rule] {None, {"\<Time (hours)\>", "\<Red Divisions\>", \
"\<Blue Divisions\>"}}]\), "\[IndentingNewLine]", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\n", 
    \(contphase = 
      ListPlot[phase, PlotRange \[Rule] {{0, 5}, {0, 2}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Divisions\>", "\<Blue Divisions\>"}]\)}], \
"Input"],

Cell["\<\
In good weather, Red wins the battle after 120 hours, with 3.00 divisions \
remaining.\
\>", "Text"],

Cell[BoxData[{
    \(\[Lambda]\  = \ 1\), "\[IndentingNewLine]", 
    \(w\  = \ 1\), "\[IndentingNewLine]", 
    \(\(f1[x_, 
          y_] = \(-w\)\ \[Lambda] \((0.05)\)\ y\  - \[Lambda]\ \((0.005)\)\ x\
\ y;\)\), "\[IndentingNewLine]", 
    \(\(f2[x_, y_] = \(-w\)\ 0.05  x\  - \ 
          0.005  x\ y;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Clear[x1, x2]\), "\n", 
    \(\(x1[0] := \ 5;\)\), "\n", 
    \(\(x2[0] := \ 2;\)\), "\n", 
    \(\(num = 25;\)\), "\n", 
    \(x1[n_] := \ \(x1[n]\  = \ \ f1[x1[n - 1], x2[n - 1]] + 
          x1[n - 1]\)\), "\n", 
    \(x2[n_] := \ \(x2[n]\  = \ \ f2[x1[n - 1], x2[n - 1]] + 
          x2[n - 1]\)\), "\n", 
    \(\(data\  = \ Table[{n, x1[n], x2[n]}, {n, 0, num}];\)\), "\n", 
    \(TableForm[data, 
      TableHeadings \[Rule] {None, {"\<Time (hours)\>", "\<Red Divisions\>", \
"\<Blue Divisions\>"}}]\), "\[IndentingNewLine]", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\n", 
    \(contphase = 
      ListPlot[phase, PlotRange \[Rule] {{0, 5}, {0, 2}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Divisions\>", "\<Blue Divisions\>"}]\)}], \
"Input"],

Cell[BoxData[
    \(Do[\[IndentingNewLine]{Clear[x1, x2, f1, 
          f2], \[IndentingNewLine]f1[x_, 
            y_] = \(-w\)\ \[Lambda] \((0.05)\)\ y\  - \[Lambda]\ \((0.005)\)\ \
x\ y, \[IndentingNewLine]f2[x_, y_] = \(-w\)\ 0.05  x\  - \ 
            0.005  x\ y, \[IndentingNewLine]x1[0] := \ 
          5, \[IndentingNewLine]x2[0] := \ 2, \[IndentingNewLine]num = 
          70, \[IndentingNewLine]x1[
            n_] := \ \(x1[n]\  = \ \ f1[x1[n - 1], x2[n - 1]] + x1[n - 1]\), 
        x2[n_] := \ \(x2[n]\  = \ \ f2[x1[n - 1], x2[n - 1]] + x2[n - 1]\), 
        data\  = \ 
          Table[{n, x1[n], x2[n]}, {n, 0, 
              num}], \[IndentingNewLine]\[IndentingNewLine]Do[{If[
              Part[data, n + 1, 2] < 0 || \ 
                Part[data, n + 1, 3] < 0, {Print["\<Battle ends after \>", 
                  Part[data, n + 1, 1], "\< hours. w = \>", 
                  w, "\< lambda = \>", \[Lambda]], Break[]}]}, {n, 0, 
            num}], \[IndentingNewLine]\[IndentingNewLine]phase\  = \ 
          Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, num}], 
        contphase = 
          ListPlot[phase, PlotRange \[Rule] {{0, 5}, {0, 2}}, 
            PlotJoined \[Rule] True, Frame \[Rule] True, 
            FrameTicks \[Rule] {{0, 1, 2, 3, 4, 5}, {0, 1, 
                  2}, {}, {}}]}, {\[Lambda], 1, 5}, {w, 0.2, 1, 
        0.2}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuous version of the battle problem", "Subsubsection"],

Cell[BoxData[
    \(Do[\[IndentingNewLine]{Clear[x1, x2, f1, 
          f2], \[IndentingNewLine]f1[x_, 
            y_] = \(-w\)\ \[Lambda] \((0.05)\)\ y\  - \[Lambda]\ \((0.005)\)\ \
x\ y, \[IndentingNewLine]f2[x_, y_] = \(-w\)\ 0.05  x\  - \ 
            0.005  x\ y, \[IndentingNewLine]x1[0] := \ 
          5, \[IndentingNewLine]x2[0] := \ 2, \[IndentingNewLine]num = 
          7000, \[IndentingNewLine]h\  = \ 
          0.01, \[IndentingNewLine]x1[
            n_] := \ \(x1[n]\  = \ \ h\ f1[x1[n - 1], x2[n - 1]] + 
              x1[n - 1]\), 
        x2[n_] := \ \(x2[n]\  = \ \ h\ f2[x1[n - 1], x2[n - 1]] + 
              x2[n - 1]\), 
        data\  = \ 
          Table[{h*n, x1[n], x2[n]}, {n, 0, 
              num}], \[IndentingNewLine]\[IndentingNewLine]Do[{If[
              Part[data, n + 1, 2] < 0 || \ 
                Part[data, n + 1, 3] < 0, {Print["\<Battle ends after \>", 
                  Part[data, n + 1, 1], "\< hours. w = \>", 
                  w, "\< lambda = \>", \[Lambda]], Break[]}]}, {n, 0, 
            num}], \[IndentingNewLine]\[IndentingNewLine]phase\  = \ 
          Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, num}], 
        contphase = 
          ListPlot[phase, PlotRange \[Rule] {{0, 5}, {0, 2}}, 
            PlotJoined \[Rule] True, Frame \[Rule] True, 
            FrameTicks \[Rule] {{0, 1, 2, 3, 4, 5}, {0, 1, 
                  2}, {}, {}}]}, {\[Lambda], 1, 5}, {w, 0.2, 1, 
        0.2}]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 59, "Section"],
Cell[1782, 54, 55, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[1862, 59, 35, 0, 43, "Subsubsection"],
Cell[1900, 61, 47, 0, 33, "Text"],
Cell[1950, 63, 280, 5, 90, "Input"],
Cell[2233, 70, 175, 5, 33, "Text"],
Cell[2411, 77, 245, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2693, 87, 43, 0, 43, "Subsubsection"],
Cell[2739, 89, 86, 2, 33, "Text"],
Cell[2828, 93, 1338, 26, 410, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4203, 124, 45, 0, 43, "Subsubsection"],
Cell[4251, 126, 1545, 30, 470, "Input"],
Cell[5799, 158, 1531, 32, 470, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7367, 195, 68, 0, 43, "Subsubsection"],
Cell[7438, 197, 151, 3, 52, "Text"],
Cell[7592, 202, 1042, 18, 410, "Input"],
Cell[8637, 222, 1043, 18, 410, "Input"],
Cell[9683, 242, 93, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9813, 248, 49, 0, 43, "Subsubsection"],
Cell[9865, 250, 92, 2, 33, "Text"],
Cell[9960, 254, 232, 3, 70, "Input"],
Cell[10195, 259, 76, 0, 33, "Text"],
Cell[10274, 261, 427, 10, 130, "Input"],
Cell[10704, 273, 495, 10, 170, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11236, 288, 38, 0, 43, "Subsubsection"],
Cell[11277, 290, 364, 6, 90, "Text"],
Cell[11644, 298, 1234, 27, 430, "Input"],
Cell[12881, 327, 110, 3, 33, "Text"],
Cell[12994, 332, 1231, 27, 430, "Input"],
Cell[14228, 361, 1388, 24, 450, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15653, 390, 65, 0, 43, "Subsubsection"],
Cell[15721, 392, 1472, 27, 470, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

