(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9217,        251]*)
(*NotebookOutlinePosition[      9859,        273]*)
(*  CellTagsIndexPosition[      9815,        269]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{
    \(<< Graphics`Graphics`\), "\n", 
    \(<< Statistics`NormalDistribution`\)}], "Input"],

Cell["Here we create the data set for the weight of 500 lab rats:", "Text"],

Cell[BoxData[
    \(\(data = RandomArray[NormalDistribution[300  Pi, 3], 500];\)\)], "Input"],

Cell["And now we will plot the data:", "Text"],

Cell[BoxData[
    \(Histogram[data, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Weight of Rat\>", "\<Frequency\>"}]\)], "Input"],

Cell["We can easily change the bin size:", "Text"],

Cell[BoxData[
    \(Histogram[data, HistogramCategories \[Rule] 50, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Weight of Rat\>", "\<Frequency\>"}]\)], "Input"],

Cell[BoxData[
    \(Histogram[data, HistogramCategories \[Rule] 5000, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Weight of Rat\>", "\<Frequency\>"}]\)], "Input"],

Cell[BoxData[
    \(Histogram[data, HistogramCategories \[Rule] 3, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Weight of Rat\>", "\<Frequency\>"}]\)], "Input"],

Cell[BoxData[
    \(Histogram[data, HistogramCategories \[Rule] 2, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Weight of Rat\>", "\<Frequency\>"}]\)], "Input"],

Cell[BoxData[
    \(Histogram[data, HistogramCategories \[Rule] 20, 
      HistogramScale \[Rule] 1, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Weight of Rat\>", "\<Probability\>"}]\)], "Input"],

Cell[CellGroupData[{

Cell["Discrete Probability", "Subsubsection"],

Cell["Here is the data for my coin toss game.", "Text"],

Cell[BoxData[{
    \(\(numclass = 4;\)\), "\[IndentingNewLine]", 
    \(\(num = 10;\)\), "\[IndentingNewLine]", 
    \(\(data2\  = \ {3, 5, 2, 0};\)\)}], "Input"],

Cell[BoxData[
    \(Histogram[data2, FrequencyData \[Rule] True, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Number of Heads\>", "\<Frequency\>"}, 
      FrameTicks \[Rule] {{{0.5, "\<0\>"}, {1.5, "\<1\>"}, {2.5, "\<2\>"}, \
{3.5, "\<3\>"}}, Automatic, {}, {}}]\)], "Input"],

Cell[BoxData[
    \(Histogram[data2, FrequencyData \[Rule] True, HistogramScale \[Rule] 1, 
      Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Number of Heads\>", "\<Probability\>"}, 
      FrameTicks \[Rule] {{{0.5, "\<0\>"}, {1.5, "\<1\>"}, {2.5, "\<2\>"}, \
{3.5, "\<3\>"}}, Automatic, {}, {}}]\)], "Input"],

Cell["\<\
Here is the check that what we have is a probability distribution:\
\>", "Text"],

Cell[BoxData[
    \(Sum[Part[data2, i]/num, {i, 1, numclass}]\)], "Input"],

Cell["The expected value:", "Text"],

Cell[BoxData[{
    \(\(Sum[\((i - 1)\)*Part[data2, i]/num, {i, 1, 
          numclass}];\)\), "\[IndentingNewLine]", 
    \(EX = \ N[%]\)}], "Input"],

Cell["The variance:", "Text"],

Cell[BoxData[{
    \(\(Sum[\((\((i - 1)\) - EX)\)^2*Part[data2, i]/num, {i, 1, 
          numclass}];\)\), "\[IndentingNewLine]", 
    \(VX = N[%]\)}], "Input"],

Cell[TextData[{
  "We can have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " run many trials for us using the random number generator to simulate \
tossing the coin. We will assume that 0 represents a head."
}], "Text"],

Cell[BoxData[{
    \(\(data3\  = \ {0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(num\  = 100000;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]{numheads = 
          0, \[IndentingNewLine]\[IndentingNewLine]Do[\[IndentingNewLine]{\
toss\  = Random[Integer], \[IndentingNewLine]If[toss \[Equal] 0, 
              numheads\  = numheads\  + \ 1]}, {j, 1, 
            3}], \[IndentingNewLine]\[IndentingNewLine]data3[\([numheads + 
                1]\)]\  = \ data3[\([numheads + 1]\)] + 1}, {i, 1, 
        num}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(data3\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Histogram[data3, FrequencyData \[Rule] True, HistogramScale \[Rule] 1, 
      Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Number of Heads\>", "\<Probability\>"}, 
      FrameTicks \[Rule] {{{0.5, "\<0\>"}, {1.5, "\<1\>"}, {2.5, "\<2\>"}, \
{3.5, "\<3\>"}}, 
          Automatic, {}, {}}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(EX\  = \ 
      N[Sum[\((i - 1)\)*Part[data3, i]/num, {i, 1, 
            Length[data3]}]]\n\), "\[IndentingNewLine]", 
    \(VX = 
      N[Sum[\((\((i - 1)\) - EX)\)^2*Part[data3, i]/num, {i, 1, 
            Length[data3]}]]\)}], "Input"],

Cell["\<\
Here is the analysis changed to to four tosses and count the number of heads:\
\
\>", "Text"],

Cell[BoxData[{
    \(\(data3\  = \ {0, 0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(num\  = 100000;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]{numheads = 
          0, \[IndentingNewLine]\[IndentingNewLine]Do[\[IndentingNewLine]{\
toss\  = Random[Integer], \[IndentingNewLine]If[toss \[Equal] 0, 
              numheads\  = numheads\  + \ 1]}, {j, 1, 
            4}], \[IndentingNewLine]\[IndentingNewLine]data3[\([numheads + 
                1]\)]\  = \ data3[\([numheads + 1]\)] + 1}, {i, 1, 
        num}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(data3\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Histogram[data3, FrequencyData \[Rule] True, HistogramScale \[Rule] 1, 
      Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Number of Heads\>", "\<Probability\>"}, 
      FrameTicks \[Rule] {{{0.5, "\<0\>"}, {1.5, "\<1\>"}, {2.5, "\<2\>"}, \
{3.5, "\<3\>"}, {4.5, "\<4\>"}}, 
          Automatic, {}, {}}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(EX\  = \ 
      N[Sum[\((i - 1)\)*Part[data3, i]/num, {i, 1, 
            Length[data3]}]]\n\), "\[IndentingNewLine]", 
    \(VX = 
      N[Sum[\((\((i - 1)\) - EX)\)^2*Part[data3, i]/num, {i, 1, 
            Length[data3]}]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuous Probability", "Subsubsection"],

Cell[BoxData[{
    \(f[x_]\  = \ 4\ x^2\ Exp[\(-2\)\ x]\), "\[IndentingNewLine]", 
    \(Plot[f[x], {x, 0, 5}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<x\>", "\<Probability\>"}]\)}], "Input"],

Cell[BoxData[
    \(Integrate[f[x], {x, 0, Infinity}]\)], "Input"],

Cell[BoxData[
    \(EX\  = \ Integrate[x\ f[x], {x, 0, Infinity}]\)], "Input"],

Cell[BoxData[
    \(VX\  = \ Integrate[\((x - EX)\)^2\ f[x], {x, 0, Infinity}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Distributions", "Subsection"],

Cell[BoxData[{
    \(a\  = \ 2\), "\[IndentingNewLine]", 
    \(b\  = \ 3\), "\[IndentingNewLine]", 
    \(f[x_]\  = \ If[x > b, 0, UnitStep[x - a]]\), "\[IndentingNewLine]", 
    \(Plot[f[x], {x, 0, 5}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<x\>", "\<Uniform Distribution\>"}]\)}], "Input"],

Cell[BoxData[
    RowBox[{"<<", 
      StyleBox[
        RowBox[{"Statistics", 
          StyleBox["`Normal",
            "MB"], "Distribution", 
          StyleBox["`",
            "MB"]}]]}]], "Input"],

Cell[BoxData[{
    \(ndist\  = NormalDistribution[12, Pi]\), "\[IndentingNewLine]", 
    \(f[x_]\  = \ PDF[ndist, x]\), "\[IndentingNewLine]", 
    \(Plot[f[x], {x, 0, 24}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<x\>", "\<Normal Distribution\>"}]\)}], "Input"],

Cell[BoxData[
    \(<< Statistics`DiscreteDistributions`\)], "Input"],

Cell[BoxData[{
    \(bdist = BinomialDistribution[34, 0.3]\), "\[IndentingNewLine]", 
    \(f[k_]\  = \ PDF[bdist, k]\), "\[IndentingNewLine]", 
    \(list\  = \ Table[{k, f[k]}, {k, 0, 34}]\), "\[IndentingNewLine]", 
    \(ListPlot[list, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<k\>", "\<Binomial Distribution\>"}]\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 106, 2, 50, "Input"],
Cell[1814, 54, 75, 0, 33, "Text"],
Cell[1892, 56, 93, 1, 30, "Input"],
Cell[1988, 59, 46, 0, 33, "Text"],
Cell[2037, 61, 134, 2, 50, "Input"],
Cell[2174, 65, 50, 0, 33, "Text"],
Cell[2227, 67, 166, 2, 50, "Input"],
Cell[2396, 71, 168, 2, 50, "Input"],
Cell[2567, 75, 165, 2, 50, "Input"],
Cell[2735, 79, 165, 2, 50, "Input"],
Cell[2903, 83, 201, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[3129, 90, 45, 0, 43, "Subsubsection"],
Cell[3177, 92, 55, 0, 33, "Text"],
Cell[3235, 94, 162, 3, 70, "Input"],
Cell[3400, 99, 280, 4, 110, "Input"],
Cell[3683, 105, 315, 5, 130, "Input"],
Cell[4001, 112, 90, 2, 33, "Text"],
Cell[4094, 116, 74, 1, 30, "Input"],
Cell[4171, 119, 35, 0, 33, "Text"],
Cell[4209, 121, 149, 3, 50, "Input"],
Cell[4361, 126, 29, 0, 33, "Text"],
Cell[4393, 128, 160, 3, 50, "Input"],
Cell[4556, 133, 232, 6, 52, "Text"],
Cell[4791, 141, 1241, 22, 550, "Input"],
Cell[6035, 165, 103, 3, 33, "Text"],
Cell[6141, 170, 1260, 22, 550, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7438, 197, 47, 0, 43, "Subsubsection"],
Cell[7488, 199, 200, 3, 70, "Input"],
Cell[7691, 204, 66, 1, 30, "Input"],
Cell[7760, 207, 78, 1, 30, "Input"],
Cell[7841, 210, 91, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7969, 216, 35, 0, 47, "Subsection"],
Cell[8007, 218, 302, 5, 110, "Input"],
Cell[8312, 225, 203, 7, 30, "Input"],
Cell[8518, 234, 270, 4, 90, "Input"],
Cell[8791, 240, 69, 1, 30, "Input"],
Cell[8863, 243, 338, 5, 110, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

