(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21614,        495]*)
(*NotebookOutlinePosition[     22257,        517]*)
(*  CellTagsIndexPosition[     22213,        513]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Deterministic Battle Simulations", "Subsubsection"],

Cell[BoxData[{
    \(\(f1[x_, y_, w_] = \(-0.015\) y\ ;\)\), "\[IndentingNewLine]", 
    \(\(f2[x_, y_, w_] = \(-0.010\) 
          x\ ;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Clear[x1, x2]\), "\[IndentingNewLine]", 
    \(\(x1[0] := \ 3000;\)\), "\n", 
    \(\(x2[0] := \ 3000;\)\), "\n", 
    \(\(num = 120;\)\n\), "\[IndentingNewLine]", 
    \(x1[n_] := \ \(x1[n] = 
        Round[f1[x1[n - 1], x2[n - 1], w[n - 1]] + x1[n - 1]]\)\), "\n", 
    \(x2[n_] := \ \(x2[n] = 
        Round[f2[x1[n - 1], x2[n - 1], w[n - 1]] + 
            x2[n - 1]]\)\[IndentingNewLine]\), "\n", 
    \(\(data\  = \ Table[{0.1*n, x1[n], x2[n]}, {n, 0, num}];\)\), "\n", 
    \(TableForm[data, 
      TableHeadings \[Rule] {None, {"\<Time (hours)\>", "\<Red Soldiers\>", "\
\<Blue Soldiers\>"}}]\), "\[IndentingNewLine]", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\n", 
    \(contphase = 
      ListPlot[phase, PlotRange \[Rule] {{0, 3000}, {0, 3000}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Soldiers\>", "\<Blue Soldiers\>"}]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Adding weather: Stochastic Effect", "Subsubsection"],

Cell[BoxData[{
    \(\(f1[x_, y_, w_] = \(-w\)\ 0.015\ y\ ;\)\), "\[IndentingNewLine]", 
    \(\(\(f2[x_, y_, w_] = \(-\ 0.010\) x\ ;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Clear[x1, x2, w]\), "\[IndentingNewLine]", 
    \(\(w[0]\  := 1.0;\)\), "\n", 
    \(\(x1[0] := \ 3000;\)\), "\n", 
    \(\(x2[0] := \ 3000;\)\), "\n", 
    \(\(\(num = 200;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(w[n_]\  := \ \(w[n]\  = \ 
        Module[{}, {next = w[n - 1]\  + \ 0.1*Random[Integer, {\(-1\), 1}], 
            If[next \[GreaterEqual] 1, \ next = 1.0], 
            If[next\  \[LessEqual] \ 0, \ next = 0.0]}; 
          next]\)\), "\[IndentingNewLine]", 
    \(x1[n_] := \ \(x1[n] = 
        Round[f1[x1[n - 1], x2[n - 1], w[n - 1]] + x1[n - 1]]\)\), "\n", 
    \(\(\(x2[n_] := \ \(x2[n] = 
        Round[f2[x1[n - 1], x2[n - 1], w[n - 1]] + x2[n - 1]]\)\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(data\  = \ 
        Table[{0.1*n, x1[n], x2[n], w[n]}, {n, 0, num}];\)\), "\n", 
    \(TableForm[data, 
      TableHeadings \[Rule] {None, {"\<Time (hours)\>", "\<Red Soldiers\>", "\
\<Blue Soldiers\>", "\<Weather\>"}}]\), "\[IndentingNewLine]", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\n", 
    \(\(\(contphase = 
      ListPlot[phase, PlotRange \[Rule] {{0, 3000}, {0, 3000}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Soldiers\>", "\<Blue Soldiers\>"}]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(weather\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 4]}, {n, 0, 
            num}];\)\), "\n", 
    \(weatherplot = 
      ListPlot[weather, PlotRange \[Rule] All, PlotJoined \[Rule] True, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Time\>", "\<Weather\>"}]\)}], "Input"],

Cell["Simulation run for 20 times.", "Text"],

Cell[BoxData[{
    \(\(f1[x_, y_, w_] = \(-w\)\ 0.015\ y\ ;\)\), "\[IndentingNewLine]", 
    \(\(\(f2[x_, y_, w_] = \(-\ 0.010\) x\ ;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]{Clear[x1, x2, w], \[IndentingNewLine]w[0]\  := 
          1.0, \nx1[0] := \ 3000, \nx2[0] := \ 3000, \n
        num = 200, \[IndentingNewLine]\n
        w[n_]\  := \ \(w[n]\  = \ 
            Module[{}, {next = 
                  w[n - 1]\  + \ 0.1*Random[Integer, {\(-1\), 1}], 
                If[next \[GreaterEqual] 1, \ next = 1.0], 
                If[next\  \[LessEqual] \ 0, \ next = 0.0]}; 
              next]\), \[IndentingNewLine]x1[n_] := \ \(x1[n] = 
            Round[f1[x1[n - 1], x2[n - 1], w[n - 1]] + x1[n - 1]]\), \n
        x2[n_] := \ \(x2[n] = 
            Round[f2[x1[n - 1], x2[n - 1], w[n - 1]] + 
                x2[n - 1]]\), \[IndentingNewLine]\n
        data\  = \ Table[{0.1*n, x1[n], x2[n], w[n]}, {n, 0, num}], \n
        TableForm[data, 
          TableHeadings \[Rule] {None, {"\<Time (hours)\>", "\<Red \
Soldiers\>", "\<Blue Soldiers\>", "\<Weather\>"}}]; \[IndentingNewLine]phase\ \
 = \ Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, num}], \n
        weather\  = \ 
          Table[{Part[data, n + 1, 1], Part[data, n + 1, 4]}, {n, 0, 
              num}], \[IndentingNewLine]\[IndentingNewLine]p1\  = \ 
          ListPlot[phase, PlotRange \[Rule] {{0, 3000}, {0, 3000}}, 
            PlotJoined \[Rule] True, Frame \[Rule] True, 
            FrameTicks \[Rule] False, 
            FrameLabel \[Rule] {"\<Red\>", "\<Blue\>"}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]p2\  = \ 
          ListPlot[weather, PlotRange \[Rule] {{0, 20}, {0, 1}}, 
            PlotJoined \[Rule] True, Frame \[Rule] True, 
            FrameTicks \[Rule] False, 
            FrameLabel \[Rule] {"\<Time\>", "\<Weather\>"}, 
            DisplayFunction \[Rule] 
              Identity]; \[IndentingNewLine]\[IndentingNewLine]Show[
          GraphicsArray[{p1, 
              p2}]]\[IndentingNewLine]\[IndentingNewLine]}, {i, 1, 
        20}]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A more realistic model of weather", "Subsubsection"],

Cell[BoxData[{
    \(\(f1[x_, y_, w_] = \(-w\)\ 0.015\ y\ ;\)\), "\[IndentingNewLine]", 
    \(\(\(f2[x_, y_, w_] = \(-\ 0.010\) x\ ;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Clear[x1, x2, w]\), "\[IndentingNewLine]", 
    \(\(w[0]\  := 0.8;\)\), "\n", 
    \(\(x1[0] := \ 3000;\)\), "\n", 
    \(\(x2[0] := \ 3000;\)\), "\n", 
    \(\(num = 200;\)\n\), "\[IndentingNewLine]", 
    \(w[n_]\  := \ \(w[n]\  = \ 
        Module[{}, {next = w[n - 1]\  + \ 0.03*Random[Integer, {\(-1\), 1}], 
            If[next \[GreaterEqual] 1, \ next = 1.0], 
            If[next\  \[LessEqual] \ 0, \ next = 0.0]}; 
          next]\)\), "\[IndentingNewLine]", 
    \(x1[n_] := \ \(x1[n] = 
        Round[f1[x1[n - 1], x2[n - 1], w[n - 1]] + x1[n - 1]]\)\), "\n", 
    \(x2[n_] := \ \(x2[n] = 
        Round[f2[x1[n - 1], x2[n - 1], w[n - 1]] + 
            x2[n - 1]]\)\[IndentingNewLine]\), "\n", 
    \(\(data\  = \ 
        Table[{0.1*n, x1[n], x2[n], w[n]}, {n, 0, num}];\)\), "\n", 
    \(TableForm[data, 
      TableHeadings \[Rule] {None, {"\<Time (hours)\>", "\<Red Soldiers\>", "\
\<Blue Soldiers\>", "\<Weather\>"}}]\), "\[IndentingNewLine]", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\n", 
    \(contphase = 
      ListPlot[phase, PlotRange \[Rule] {{0, 3000}, {0, 3000}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Soldiers\>", "\<Blue Soldiers\>"}]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(weather\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 4]}, {n, 0, 
            num}];\)\), "\n", 
    \(weatherplot = 
      ListPlot[weather, PlotRange \[Rule] {{0, 20}, {0, 1}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Time\>", "\<Weather\>"}]\)}], "Input"],

Cell[BoxData[{
    \(\(f1[x_, y_, w_] = \(-w\)\ 0.015\ y\ ;\)\), "\[IndentingNewLine]", 
    \(\(\(f2[x_, y_, w_] = \(-\ 0.010\) x\ ;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]{Clear[x1, x2, w], \[IndentingNewLine]w[0]\  := 
          0.8, \nx1[0] := \ 3000, \nx2[0] := \ 3000, \n
        num = 300, \[IndentingNewLine]\n
        w[n_]\  := \ \(w[n]\  = \ 
            Module[{}, {next = 
                  w[n - 1]\  + \ 0.03*Random[Integer, {\(-1\), 1}], 
                If[next \[GreaterEqual] 1, \ next = 1.0], 
                If[next\  \[LessEqual] \ 0, \ next = 0.0]}; 
              next]\), \[IndentingNewLine]x1[n_] := \ \(x1[n] = 
            Round[f1[x1[n - 1], x2[n - 1], w[n - 1]] + x1[n - 1]]\), \n
        x2[n_] := \ \(x2[n] = 
            Round[f2[x1[n - 1], x2[n - 1], w[n - 1]] + 
                x2[n - 1]]\), \[IndentingNewLine]\n
        data\  = \ Table[{0.1*n, x1[n], x2[n], w[n]}, {n, 0, num}], \n
        TableForm[data, 
          TableHeadings \[Rule] {None, {"\<Time (hours)\>", "\<Red \
Soldiers\>", "\<Blue Soldiers\>", "\<Weather\>"}}]; \[IndentingNewLine]phase\ \
 = \ Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, num}], \n
        weather\  = \ 
          Table[{Part[data, n + 1, 1], Part[data, n + 1, 4]}, {n, 0, 
              num}], \[IndentingNewLine]\[IndentingNewLine]p1\  = \ 
          ListPlot[phase, PlotRange \[Rule] {{0, 3000}, {0, 3000}}, 
            PlotJoined \[Rule] True, Frame \[Rule] True, 
            FrameTicks \[Rule] False, 
            FrameLabel \[Rule] {"\<Red\>", "\<Blue\>"}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]p2\  = \ 
          ListPlot[weather, PlotRange \[Rule] {{0, 20}, {0, 1}}, 
            PlotJoined \[Rule] True, Frame \[Rule] True, 
            FrameTicks \[Rule] False, 
            FrameLabel \[Rule] {"\<Time\>", "\<Weather\>"}, 
            DisplayFunction \[Rule] 
              Identity]; \[IndentingNewLine]\[IndentingNewLine]Show[
          GraphicsArray[{p1, 
              p2}]]\[IndentingNewLine]\[IndentingNewLine]}, {i, 1, 
        20}]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Stochastic Model", "Subsection"],

Cell[BoxData[{
    \(Clear[x, y, data]\), "\[IndentingNewLine]", 
    \(\(Probability[x_, y_]\  = \ 
        0.15\ y/\((0.15\ y\  + \ 
                0.1\ x)\);\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(x[0] := 3000\), "\[IndentingNewLine]", 
    \(y[0] := 3000\), "\[IndentingNewLine]", 
    \(\(data\  = \ {};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(n = 0;\)\), "\[IndentingNewLine]", 
    \(While[
      x[n] > 0 && y[n] > 0, \[IndentingNewLine]n = 
        n + 1; \[IndentingNewLine]death\  = \ 
        Random[Real, {0, 1}]; \[IndentingNewLine]If[
        death\  < Probability[x[n - 1], y[n - 1]]\ , {y[n]\  = \ y[n - 1], 
          x[n]\  = \ x[n - 1] - 1}, {y[n]\  = \ y[n - 1] - 1, 
          x[n]\  = \ x[n - 1]}]; \[IndentingNewLine]data\  = \ 
        Append[data, {x[n], 
            y[n]}]\[IndentingNewLine]]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(Last[data]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(p1\  = \ 
      ListPlot[data, PlotRange \[Rule] {{0, 3000}, {0, 3000}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Soldiers\>", "\<Blue Soldiers\>"}]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(p2\  = \ 
      ListPlot[data, PlotRange \[Rule] {{2950, 3000}, {2950, 3000}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Soldiers\>", "\<Blue Soldiers\>"}]\)}], \
"Input"],

Cell["\<\
Here is 100 runs of the stochastic model, to see how many Blue soldiers are \
left 
after the battle. We need to load the Graphics package to do histograms:\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[BoxData[{
    \(Clear[data2]\), "\[IndentingNewLine]", 
    \(\(data2 = {};\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]\[IndentingNewLine]{Clear[x, y, 
          data], \[IndentingNewLine]Probability[x_, y_]\  = \ 
          0.15\ y/\((0.15\ y\  + \ 
                  0.1\ x)\), \[IndentingNewLine]\[IndentingNewLine]x[0] := 
          3000, \[IndentingNewLine]y[0] := 
          3000, \[IndentingNewLine]data\  = \ {}, \[IndentingNewLine]\
\[IndentingNewLine]n = 0, \[IndentingNewLine]While[
          x[n] > 0 && y[n] > 0, \[IndentingNewLine]n = 
            n + 1; \[IndentingNewLine]death\  = \ 
            Random[Real, {0, 1}]; \[IndentingNewLine]If[
            death\  < 
              Probability[x[n - 1], y[n - 1]]\ , {y[n]\  = \ y[n - 1], 
              x[n]\  = \ x[n - 1] - 1}, {y[n]\  = \ y[n - 1] - 1, 
              x[n]\  = \ x[n - 1]}]; \[IndentingNewLine]data\  = \ 
            Append[data, {x[n], 
                y[n]}]\[IndentingNewLine]], \[IndentingNewLine]\
\[IndentingNewLine]final\  = \ 
          Part[Last[data], 2], \[IndentingNewLine]data2 = 
          Append[data2, final]}, \[IndentingNewLine]{i, 1, 100}]\)}], "Input"],

Cell[BoxData[
    \(data2\)], "Input"],

Cell[BoxData[
    \(histy1 = 
      Histogram[data2, HistogramCategories \[Rule] 5, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Final Blue Soldiers\>", "\<Frequency\>"}]\)], \
"Input"],

Cell[BoxData[
    \(histy2 = 
      Histogram[data2, HistogramCategories \[Rule] 5, Frame \[Rule] True, 
        HistogramScale \[Rule] 1, 
        FrameLabel \[Rule] {"\<Final Blue Soldiers\>", \
"\<Probability\>"}]\)], "Input"],

Cell[BoxData[{
    \(s\  = \ 50\), "\[IndentingNewLine]", 
    \(fit2\  = \ 
      Plot[\(1/Sqrt[2  Pi]\)\ /s*Exp[\(\(-\((x - 1725)\)^2\)/2\)/s^2], {x, 
          1550, 1900}]\), "\[IndentingNewLine]", 
    \(Show[histy2, fit2]\)}], "Input"],

Cell[CellGroupData[{

Cell["Include time in the stochastic model", "Subsubsection"],

Cell[BoxData[{
    \(Clear[x, y, t, data]\), "\[IndentingNewLine]", 
    \(\(Probability[x_, y_]\  = \ 
        0.15\ y/\((0.15\ y\  + \ 0.1\ x)\);\)\), "\[IndentingNewLine]", 
    \(\(Probabilitytime[x_, y_]\  = \ 
        1.0/\((0.15\ y\  + \ 
              0.1\ x)\);\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(x[0] := 3000\), "\[IndentingNewLine]", 
    \(y[0] := 3000\), "\[IndentingNewLine]", 
    \(t[0]\  := \ 0\), "\[IndentingNewLine]", 
    \(\(data\  = \ {};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(n = 0;\)\), "\[IndentingNewLine]", 
    \(While[
      x[n] > 0 && y[n] > 0, \[IndentingNewLine]n = 
        n + 1; \[IndentingNewLine]death\  = \ 
        Random[Real, {0, 1}]; \[IndentingNewLine]t[n]\  = \ 
        t[n - 1]\  - 
          Log[death]*
            Probabilitytime[x[n - 1], 
              y[n - 1]]; \[IndentingNewLine]nfinal\  = \ 
        n; \[IndentingNewLine]If[
        death\  < Probability[x[n - 1], y[n - 1]]\ , {y[n]\  = \ y[n - 1], 
          x[n]\  = \ x[n - 1] - 1}, {y[n]\  = \ y[n - 1] - 1, 
          x[n]\  = \ x[n - 1]}]; \[IndentingNewLine]data\  = \ 
        Append[data, {x[n], 
            y[n]}]\[IndentingNewLine]]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(t[nfinal]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(p1\  = \ 
      ListPlot[data, PlotRange \[Rule] {{0, 3000}, {0, 3000}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Soldiers\>", "\<Blue Soldiers\>"}]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(p2\  = \ 
      ListPlot[data, PlotRange \[Rule] {{2950, 3000}, {2950, 3000}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Red Soldiers\>", "\<Blue Soldiers\>"}]\)}], \
"Input"],

Cell["\<\
Include time,  and do many runs and get a histogram for the duration of the \
battle.\
\>", "Text"],

Cell[BoxData[{
    \(Clear[data2]\), "\[IndentingNewLine]", 
    \(\(data2 = {};\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]\[IndentingNewLine]{Clear[x, y, t, 
          data], \[IndentingNewLine]Probability[x_, y_]\  = \ 
          0.15\ y/\((0.15\ y\  + \ 
                  0.1\ x)\), \[IndentingNewLine]Probabilitytime[x_, y_]\  = \ 
          1.0/\((0.15\ y\  + \ 
                0.1\ x)\), \[IndentingNewLine]\[IndentingNewLine]x[0] := 
          3000, \[IndentingNewLine]y[0] := 3000, \[IndentingNewLine]t[0] := 
          0, \[IndentingNewLine]data\  = \ {}, \[IndentingNewLine]\
\[IndentingNewLine]n = 0, \[IndentingNewLine]While[
          x[n] > 0 && y[n] > 0, \[IndentingNewLine]n = 
            n + 1; \[IndentingNewLine]nfinal\  = \ 
            n; \[IndentingNewLine]death\  = \ 
            Random[Real, {0, 1}]; \[IndentingNewLine]t[n]\  = \ 
            t[n - 1]\  - 
              Log[death]*
                Probabilitytime[x[n - 1], y[n - 1]]; \[IndentingNewLine]If[
            death\  < 
              Probability[x[n - 1], y[n - 1]]\ , {y[n]\  = \ y[n - 1], 
              x[n]\  = \ x[n - 1] - 1}, {y[n]\  = \ y[n - 1] - 1, 
              x[n]\  = \ x[n - 1]}]; \[IndentingNewLine]data\  = \ 
            Append[data, {x[n], 
                y[n]}]\[IndentingNewLine]], \[IndentingNewLine]\
\[IndentingNewLine]data2 = Append[data2, t[nfinal]]}, \[IndentingNewLine]{i, 
        1, 100}]\)}], "Input"],

Cell[BoxData[
    \(data2\)], "Input"],

Cell["What is the mean duration of the battle:", "Text"],

Cell[BoxData[
    \(Sum[Part[data2, n], {n, 1, 100}]/100\)], "Input"],

Cell[BoxData[
    \(histy1 = 
      Histogram[data2, HistogramCategories \[Rule] 8, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<Duration of Battle\>", "\<Frequency\>"}]\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Stochastic Model with weather", "Subsubsection"],

Cell[BoxData[{
    \(Clear[data2]\), "\[IndentingNewLine]", 
    \(\(data2 = {};\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]\[IndentingNewLine]{Clear[x, y, w, t, nfinal, 
          data, weather], \[IndentingNewLine]Probability[x_, y_, w_]\  = \ 
          w*0.15\ y/\((w*0.15\ y\  + \ 
                  0.1\ x)\), \[IndentingNewLine]Probabilitytime[x_, y_, 
            w_]\  = \ 
          1.0/\((w*0.15\ y\  + \ 
                0.1\ x)\), \[IndentingNewLine]\[IndentingNewLine]x[0] := 
          3000, \[IndentingNewLine]y[0] := 3000, \[IndentingNewLine]t[0] := 
          0, \[IndentingNewLine]w[0] := 
          0.8, \[IndentingNewLine]data\  = \ {}, \[IndentingNewLine]weather = \
{}, \[IndentingNewLine]\[IndentingNewLine]n = 0, \[IndentingNewLine]While[
          x[n] > 0 && y[n] > 0, \[IndentingNewLine]n = 
            n + 1; \[IndentingNewLine]nfinal\  = \ 
            n; \[IndentingNewLine]death\  = \ 
            Random[Real, {0, 1}]; \[IndentingNewLine]t[n]\  = \ 
            t[n - 1]\  - 
              Log[death]*
                Probabilitytime[x[n - 1], y[n - 1], 
                  w[n - 1]]; \[IndentingNewLine]w[n]\  = \ 
            Module[{}, {next = 
                  w[n - 1]\  + \ 0.005*Random[Integer, {\(-1\), 1}], 
                If[next \[GreaterEqual] 1, \ next = 1.0], 
                If[next\  \[LessEqual] \ 0, \ next = 0.0]}; 
              next]; \[IndentingNewLine]If[
            death\  < 
              Probability[x[n - 1], y[n - 1], w[n - 1]]\ , {y[n]\  = \ 
                y[n - 1], x[n]\  = \ x[n - 1] - 1}, {y[n]\  = \ y[n - 1] - 1, 
              x[n]\  = \ x[n - 1]}]; \[IndentingNewLine]data\  = \ 
            Append[data, {x[n], y[n]}]; \[IndentingNewLine]weather = 
            Append[weather, {t[n], 
                w[n]}]\[IndentingNewLine]], \[IndentingNewLine]\
\[IndentingNewLine]p1\  = \ 
          ListPlot[data, PlotRange \[Rule] {{0, 3000}, {0, 3000}}, 
            PlotJoined \[Rule] True, Frame \[Rule] True, 
            FrameTicks \[Rule] False, 
            FrameLabel \[Rule] {"\<Red\>", "\<Blue\>"}, 
            DisplayFunction \[Rule] Identity], \[IndentingNewLine]p2\  = \ 
          ListPlot[weather, PlotRange \[Rule] {{0, t[nfinal]}, {0, 1}}, 
            PlotJoined \[Rule] True, Frame \[Rule] True, 
            FrameTicks \[Rule] False, 
            FrameLabel \[Rule] {"\<Time\>", "\<Weather\>"}, 
            DisplayFunction \[Rule] Identity], \[IndentingNewLine]Show[
          GraphicsArray[{p1, 
              p2}]], \[IndentingNewLine]\[IndentingNewLine]Print["\<Final \
Population: Red \>", Part[Last[data], 1], "\<, \>", "\< Blue \>", 
          Part[Last[data], 2], "\<.\>", "\< Duration \>", 
          Part[Last[weather], 
            1], "\<.\>"], \[IndentingNewLine]}, \[IndentingNewLine]{i, 1, 
        20}]\)}], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{543, 563},
WindowMargins->{{12, Automatic}, {Automatic, 5}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 57, 0, 43, "Subsubsection"],
Cell[1787, 54, 1162, 24, 410, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2986, 83, 58, 0, 43, "Subsubsection"],
Cell[3047, 85, 1886, 40, 650, "Input"],
Cell[4936, 127, 44, 0, 33, "Text"],
Cell[4983, 129, 2132, 38, 810, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7152, 172, 58, 0, 43, "Subsubsection"],
Cell[7213, 174, 1867, 38, 650, "Input"],
Cell[9083, 214, 2133, 38, 810, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11253, 257, 40, 0, 47, "Subsection"],
Cell[11296, 259, 1441, 29, 530, "Input"],
Cell[12740, 290, 180, 4, 52, "Text"],
Cell[12923, 296, 54, 1, 30, "Input"],
Cell[12980, 299, 1174, 21, 490, "Input"],
Cell[14157, 322, 38, 1, 30, "Input"],
Cell[14198, 325, 192, 4, 70, "Input"],
Cell[14393, 331, 229, 5, 70, "Input"],
Cell[14625, 338, 241, 5, 90, "Input"],

Cell[CellGroupData[{
Cell[14891, 347, 61, 0, 43, "Subsubsection"],
Cell[14955, 349, 1779, 37, 630, "Input"],
Cell[16737, 388, 109, 3, 33, "Text"],
Cell[16849, 393, 1439, 26, 570, "Input"],
Cell[18291, 421, 38, 1, 30, "Input"],
Cell[18332, 424, 56, 0, 33, "Text"],
Cell[18391, 426, 69, 1, 30, "Input"],
Cell[18463, 429, 191, 4, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18691, 438, 56, 0, 43, "Subsubsection"],
Cell[18750, 440, 2836, 51, 950, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

