(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6619,        212]*)
(*NotebookOutlinePosition[      7261,        234]*)
(*  CellTagsIndexPosition[      7217,        230]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Worksheet"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Problem 1", "Subsubsection"],

Cell["First define the function.", "Text"],

Cell[BoxData[
    \(f[x_, 
        y_]\  = \ \((2\ x^3 + y^3 - 3  x\ y)\)\ Exp[\(-x^2\) - 
            y^2]\)], "Input"],

Cell["Then, generate the 3D plot.", "Text"],

Cell[BoxData[
    \(plot1\  = \ 
      Plot3D[f[x, y], {x, \(-2\), 2}, {y, \(-2\), 2}, PlotPoints \[Rule] 25, 
        PlotRange \[Rule] {\(-1\), 1}]\)], "Input"],

Cell["\<\
Now, view the plot from many angles. From these we see that we have an \
absolute max at one point and an absolute min at one point.\
\>", "Text"],

Cell[BoxData[
    \(Show[plot1, ViewPoint \[Rule] {2, 2, 0}, 
      AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}]\)], "Input"],

Cell[BoxData[
    \(Show[plot1, ViewPoint \[Rule] {\(-2\), 2, 0}, 
      AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}]\)], "Input"],

Cell[BoxData[
    \(Show[plot1, ViewPoint \[Rule] {2, \(-2\), 1}, 
      AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}]\)], "Input"],

Cell["\<\
Solve the equations to find the values. The symbolic solver produces \
something which is hard to interpret.\
\>", "Text"],

Cell[BoxData[{
    \(eq1\  = \ D[f[x, y], x] \[Equal] 0\), "\[IndentingNewLine]", 
    \(eq2\  = \ D[f[x, y], y] \[Equal] 0\), "\[IndentingNewLine]", 
    \(Solve[{eq1, eq2}, {x, y}]\)}], "Input"],

Cell["Load the NonReal package.", "Text"],

Cell[BoxData[
    \(<< Miscellaneous`RealOnly`\)], "Input"],

Cell["Solve the system of equations numerically.", "Text"],

Cell[BoxData[{
    \(eq1\  = \ D[f[x, y], x] \[Equal] 0\), "\[IndentingNewLine]", 
    \(eq2\  = \ D[f[x, y], y] \[Equal] 0\), "\[IndentingNewLine]", 
    \(NSolve[{eq1, eq2}, {x, y}]\)}], "Input"],

Cell[BoxData[
    \(Show[plot1, AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}]\)], "Input"],

Cell["Generate the contour plot of the surface.", "Text"],

Cell[BoxData[
    \(ContourPlot[f[x, y], {x, \(-2\), 2}, {y, \(-2\), 2}, 
      Contours \[Rule] 20, PlotPoints \[Rule] 100]\)], "Input"],

Cell["\<\
If we evaluate the function at the points we can determine the absolute max \
and absolute min.\
\>", "Text"],

Cell[BoxData[{
    \(f[\(-1.022\), \(-0.5026\)]\), "\[IndentingNewLine]", 
    \(f[\(-0.4349\), 1.003]\), "\[IndentingNewLine]", 
    \(f[0. , 0. ]\), "\[IndentingNewLine]", 
    \(f[0.4663, 0.56098]\), "\[IndentingNewLine]", 
    \(f[1.0936, \(-0.3761\)]\), "\[IndentingNewLine]", 
    \(f[1.1037, 1.5353]\)}], "Input"],

Cell["\<\
To see numerically that the last point in a saddle point, we add a small \
amount to each variable in turn, and note that by moving away from the saddle \
point in y decreases the value of the function, yet moving away from the \
point in x increases the value of the function.\
\>", "Text"],

Cell[BoxData[{
    \(f[1.1037, 1.5353]\), "\[IndentingNewLine]", 
    \(f[1.1037, 1.5353 + 0.01]\), "\[IndentingNewLine]", 
    \(f[1.1037 + 0.01, 1.5353]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 2", "Subsubsection"],

Cell[BoxData[
    \(Table[
      Show[plot1, ViewPoint \[Rule] {5  Abs[n], 5  Abs[n], 3}, 
        Axes \[Rule] False, ColorFunction \[Rule] Hue, Mesh \[Rule] True, 
        Boxed \[Rule] False], {n, \(-5\), 5, 0.302}]\)], "Input"],

Cell[BoxData[{
    \(num\  = \ 30\), "\[IndentingNewLine]", 
    \(Table[
      Show[plot1, ViewPoint \[Rule] {5  Cos[n], 5  Sin[n], 0}, 
        Axes \[Rule] False, ColorFunction \[Rule] Hue, Mesh \[Rule] True, 
        Boxed \[Rule] False, AspectRatio \[Rule] 1], {n, 0, 
        2  Pi - 2  Pi/num, 2  Pi/num}]\)}], "Input"],

Cell["\<\
You can load an animation package which does some nice animation things for \
you:\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input"],

Cell[BoxData[
    \(SpinShow[plot1, Frames \[Rule] 10, 
      SpinRange \[Rule] {0\ Degree, 180\ Degree}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 3", "Subsubsection"],

Cell[BoxData[{
    \(Clear[y, x, k]\), "\[IndentingNewLine]", 
    \(deq\  = \ \(y'\)[x]\  \[Equal] \ 
        x^2\ y[x]\  + \ \ y[x]^2\), "\[IndentingNewLine]", 
    \(DSolve[deq, y[x], x]\), "\[IndentingNewLine]", 
    \(DSolve[{deq, y[0] \[Equal] k}, y[x], x]\), "\[IndentingNewLine]", 
    \(sol[x_, k_]\  = \ Part[%, 1, 1, 2]\)}], "Input"],

Cell["These solutions are complex valued.", "Text"],

Cell[BoxData[{
    \(Re[sol[0.75, \(-1\)]]\), "\[IndentingNewLine]", 
    \(Im[sol[0.75, \(-1\)]]\)}], "Input"],

Cell["Here is a plot of the real part.", "Text"],

Cell[BoxData[
    \(Table[Plot[Re[sol[x, n]], {x, \ 0, 2}], {n, \(-1\), 1}]\)], "Input"],

Cell[BoxData[{
    \(Simplify[sol[x, \(-1\)]]\), "\[IndentingNewLine]", 
    \(Simplify[sol[x, 0]]\), "\[IndentingNewLine]", 
    \(Simplify[sol[x, 1]]\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 100, 4, 48, "Subsection"],

Cell[CellGroupData[{
Cell[1852, 60, 34, 0, 43, "Subsubsection"],
Cell[1889, 62, 42, 0, 33, "Text"],
Cell[1934, 64, 120, 3, 30, "Input"],
Cell[2057, 69, 43, 0, 33, "Text"],
Cell[2103, 71, 162, 3, 50, "Input"],
Cell[2268, 76, 156, 3, 52, "Text"],
Cell[2427, 81, 127, 2, 50, "Input"],
Cell[2557, 85, 132, 2, 50, "Input"],
Cell[2692, 89, 132, 2, 50, "Input"],
Cell[2827, 93, 132, 3, 52, "Text"],
Cell[2962, 98, 196, 3, 70, "Input"],
Cell[3161, 103, 41, 0, 33, "Text"],
Cell[3205, 105, 59, 1, 30, "Input"],
Cell[3267, 108, 58, 0, 33, "Text"],
Cell[3328, 110, 197, 3, 70, "Input"],
Cell[3528, 115, 91, 1, 30, "Input"],
Cell[3622, 118, 57, 0, 33, "Text"],
Cell[3682, 120, 137, 2, 50, "Input"],
Cell[3822, 124, 119, 3, 52, "Text"],
Cell[3944, 129, 320, 6, 130, "Input"],
Cell[4267, 137, 301, 5, 90, "Text"],
Cell[4571, 144, 168, 3, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4776, 152, 34, 0, 43, "Subsubsection"],
Cell[4813, 154, 231, 4, 70, "Input"],
Cell[5047, 160, 326, 6, 110, "Input"],
Cell[5376, 168, 106, 3, 33, "Text"],
Cell[5485, 173, 55, 1, 30, "Input"],
Cell[5543, 176, 118, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5698, 183, 34, 0, 43, "Subsubsection"],
Cell[5735, 185, 344, 6, 110, "Input"],
Cell[6082, 193, 51, 0, 33, "Text"],
Cell[6136, 195, 111, 2, 50, "Input"],
Cell[6250, 199, 48, 0, 33, "Text"],
Cell[6301, 201, 88, 1, 30, "Input"],
Cell[6392, 204, 199, 4, 90, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

