(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24862,        621]*)
(*NotebookOutlinePosition[     25606,        646]*)
(*  CellTagsIndexPosition[     25562,        642]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Problem 2.4.6 Computer Sales", "Section"],

Cell[TextData[{
  StyleBox["NOTE: This is an unevaluated ",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  StyleBox[" notebook!",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell["\<\
A manufacturer of personal computers currently sells 10,000 units per month \
of a basic model. The cost of manufacture is $700/unit, and the wholesale \
price is $950. During the last quarter the manufacturer lowered the price \
$100 in a few test markets, and the result was a 50% increase in sales. The \
company has been advertising its product nationwide at a cost of $50,000 per \
month. The advertising agency claims that increasing the advertising budget \
by $10,000/month would result in a sales increase of 200 units/month. \
Management has agreed to consider an increase in the advertising budget to no \
more than $100,000/month.

Determine the price and the advertising budget that will maximize the profit.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["The Question", "Subsubsection"],

Cell[TextData[{
  "The variables in this problem are, with the units in brackets, and any \
constants which the problem provides given:\n\n",
  Cell[BoxData[GridBox[{
          {"Variable", "Definition", "Units", \(Constant/Variable\)},
          {Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`nc\)]]]], \(number\ of\ computers\ \
currently\ sold\), \(units/month\), \(constant, 10000\ units/month\)},
          {Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`mc\)]]]], \(cost\ of\ manufacture\), \($/
              unit\), \(constant, $700/unit\)},
          {Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`wp\)]]]], \(wholesale\ price\), \($/
              unit\), \(constant, $950/unit\)},
          {Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`pr\)]]]], \(price\ reduction\), \($/
              unit\), \(constant, $100/unit\)},
          {"prsi", \(price\ reduction\ sales\ increase\), \(%, \ 
            no\ unit\), \(constant, 50  %\)},
          {"ab", \(advertising\ budget\), \($/month\), "variable"},
          {
            "abi", \(advertising\ budget\ increase\), \($/
              month\), \(constant, \ $10\ 000/month\)},
          {
            "abisi", \(ad\ budget\ increase\ sales\ increase\), \(units/
              month\), \(constant, \ 200\ units/month\)},
          {"n", \(number\ of\ computers\ sold\), \(units/month\), 
            "variable"},
          {"P", "profit", \($/month\), "variable"},
          {"pc", \(price\ per\ computer\), \($/unit\), "variable"},
          {
            "cab", \(current\ ad\ budget\), \($/
              month\), \(constant, \ $50\ 000/month\)}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]],
  "\n"
}], "Text"],

Cell[TextData[{
  "The number of computers sold is given by either:\nn = nc* (1 + (wp-pc)/pr \
* prsi) +  (ab - cab)/abi * abisi\nor\nn=(nc+(ab-cab)/abi*abisi) \
(1+(wp-pc)/pr*prsi).\nThe first equation decouples the increase in sales due \
to a reduced price and the increase in sales due to the increased ad budget. \
The second equation says that the ad budget will change the number of \
computers sold, and then the decrease in price will increase the sales by a \
percentage of those sales.\n\nThe profit is given by:\nProfit = n * (pc-mc) - \
ab\n\nThe constraints for this problem are:\nab ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[LessEqual]\)\(\ \)\($100\ 000\)\)\)]],
  "/ month. (constraint given by management)\npc ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GreaterEqual]\)\(\ \)\)\)]],
  "$700 / unit. (or we will be selling the computers for less than they cost \
to make)\n\nWe want to find the price and the advertising budget which will \
maximize the profit."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select the modeling approach", "Subsection"],

Cell["\<\
We will model this problem as a two dimensional constrained optimization. We \
will solve using Lagrange multipliers.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formulate the model", "Subsection"],

Cell["\<\
We wish to maximize the profit. Without any changes in price or advertising, \
the profits would remain at $2.45M/month.
The constants in the problem are given as:\
\>", "Text"],

Cell[BoxData[{
    \(\(nc\  = \ 10000;\)\), "\[IndentingNewLine]", 
    \(\(mc\  = \ 700;\)\), "\[IndentingNewLine]", 
    \(\(wp\  = 950;\)\), "\[IndentingNewLine]", 
    \(\(pr\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(prsi\  = \ 50/100;\)\), "\[IndentingNewLine]", 
    \(\(abi\  = \ 10000;\)\), "\[IndentingNewLine]", 
    \(\(abisi\  = \ 200;\)\), "\[IndentingNewLine]", 
    \(\(cab\  = \ 50000;\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
We can now look at the two different ways of modeling the number of computers \
sold. I will do this with contour plots.

First, we can plot the number of computers sold modeled with the two types of \
increase (ad budget and price reduction) uncoupled. This function, along with \
the resulting profits, is contained in the following diagrams.\
\>", "Text"],

Cell[BoxData[{
    \(n = 
      nc*\((1 + \((wp - pc)\)/pr*prsi)\) + \((ab - cab)\)/abi*
          abisi\), "\[IndentingNewLine]", 
    \(plot1\  = \ 
      ContourPlot[n, {pc, 700, 950}, {ab, 50000, 200000}, 
        Contours \[Rule] 10, PlotPoints \[Rule] 40, 
        FrameLabel \[Rule] {"\<Price\>", "\<Ad Budget\>"}]\), "\
\[IndentingNewLine]", 
    \(Profit[pc_, ab_]\  = \ 
      Simplify[n*\((pc - mc)\) - ab]\), "\[IndentingNewLine]", 
    \(Plot3D[Profit[pc, ab], {pc, 700, 1100}, {ab, 50000, 150000}, 
      PlotRange \[Rule] {0, 3200000}, ViewPoint \[Rule] {1, \(-1\), 1}, 
      ColorFunction \[Rule] Hue, 
      AxesLabel \[Rule] {"\<Price\>", "\<Ad Budget\>", "\<Profit\>"}]\)}], \
"Input",
  CellLabel->"In[9]:="],

Cell["\<\
Secondly, we can plot the number of computers sold as modeled by coupling the \
two types if increase. The results follow.\
\>", "Text"],

Cell[BoxData[{
    \(n = \((nc + \((ab - cab)\)/abi*abisi)\)\ \((1 + \((wp - pc)\)/pr*
              prsi)\)\), "\[IndentingNewLine]", 
    \(plot1\  = \ 
      ContourPlot[n, {pc, 700, 950}, {ab, 50000, 200000}, 
        Contours \[Rule] 10, PlotPoints \[Rule] 40, 
        FrameLabel \[Rule] {"\<Price\>", "\<Ad Budget\>"}]\), "\
\[IndentingNewLine]", 
    \(Profit[pc_, ab_]\  = \ 
      Simplify[n*\((pc - mc)\) - ab]\), "\[IndentingNewLine]", 
    \(Plot3D[Profit[pc, ab], {pc, 700, 1100}, {ab, 50000, 150000}, 
      PlotRange \[Rule] {0, 3200000}, ViewPoint \[Rule] {1, \(-1\), 1}, 
      ColorFunction \[Rule] Hue, 
      AxesLabel \[Rule] {"\<Price\>", "\<Ad Budget\>", "\<Profit\>"}]\)}], \
"Input",
  CellLabel->"In[13]:="],

Cell["\<\
We can see the difference in the contour plots of the number of computers \
sold, as well in the three dimensional plots of the profit. At this point we \
have to choose which model to use. I am going to use the uncoupled model, \
because the justifications for each way to increase profits seems to be \
independent of the other. Therefore, I will assume the profits are given by\
\>", "Text"],

Cell[BoxData[{
    \(\(n = 
        nc*\((1 + \((wp - pc)\)/pr*prsi)\) + \((ab - cab)\)/abi*
            abisi;\)\), "\[IndentingNewLine]", 
    \(Profit[pc_, ab_]\  = \ Simplify[n*\((pc - mc)\) - ab]\)}], "Input",
  CellLabel->"In[17]:="],

Cell["The contour plot of the profit looks like:", "Text"],

Cell[BoxData[
    \(contour1\  = \ 
      ContourPlot[Profit[pc, ab], {pc, 700, 1000}, {ab, 50000, 150000}, 
        Contours \[Rule] 30, PlotPoints \[Rule] 40, 
        FrameLabel \[Rule] {"\<Price\>", "\<Ad Budget\>"}]\)], "Input",
  CellLabel->"In[19]:="],

Cell["\<\
From this, it looks like the maximum profit will occur if we have an \
advertising budget of $100,000/month and sell the computers for around $930/ \
unit.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Unit Check: ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " \t\nn: ",
  Cell[BoxData[
      \(TraditionalForm\`\([units/
            month]\)\  = \ \(\([units/month]\)\ \((\ 
                1\  + \ \(\(\([$/unti]\)\  - \ \([$/unit]\)\)\/\([$/unit]\)\)[
                    no\ \ \ unit]\ )\)\  + \ \(\(\([$/month]\)\  - \ \([$/
                        month]\)\)\/\([$/month]\)\)[
              units/month]\  = \ \([units/month]\)\)\)]],
  "\nProfit: ",
  Cell[BoxData[
      \(TraditionalForm\`\([$/
            month]\)\  = \ \(\([unit/
                  month]\)\ \((\ \([$/unit]\)\  - \ \([$/
                      unit]\))\)\  - \ \([$/month]\)\  = \ \([$/
              month]\)\)\)]],
  "\nThe units are ok!"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve the model and answer the question", "Subsection"],

Cell["\<\
Now, we wish to solve the model. We will do this using the method of Lagrange \
multipliers. First, let's examine the feasible region and see what we can \
guess about the solution. We have a feasible region which is given below.\
\>", "Text"],

Cell[BoxData[
    \(region\  = \ 
      Plot[100000, {pc, 700, 1000}, 
        PlotRange \[Rule] {50000, 150000}]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(Show[contour1, region]\)], "Input",
  CellLabel->"In[21]:="],

Cell[TextData[{
  "The feasible region includes ",
  Cell[BoxData[
      \(TraditionalForm\`pc \[GreaterEqual] 700, \ 
      ab\  \[LessEqual] \ 100\ 000\)]],
  ". We can see that the profit would increase if we could relax the \
restriction that the advertising budget had to be less than $100 000 / month. \
Let's solve the problem using Lagrange multipliers and see what we find. The \
constraint we are interested in is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(g(pc, ab)\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`ab = 100000\)]],
  ". We can tell from the contour plot that the global maximum profit will \
lie outside our constraint region, and the maximum profit will occur \
somewhere along this constraint line, at the point where the level curve for \
the profit touches the line and has a horizontal tangent."
}], "Text"],

Cell[BoxData[{
    \(\(g[pc_, ab_]\  = \ ab;\)\), "\[IndentingNewLine]", 
    \(\(eq1\  = \ 
        D[Profit[pc, ab], pc]\  \[Equal] \ 
          LM\ D[g[pc, ab], pc];\)\), "\[IndentingNewLine]", 
    \(\(eq2\  = \ 
        D[Profit[pc, ab], ab]\  \[Equal] \ 
          LM\ D[g[pc, ab], ab];\)\), "\[IndentingNewLine]", 
    \(\(eq3\  = \ g[pc, ab] \[Equal] 100000;\)\), "\[IndentingNewLine]", 
    \(Solve[{eq1, eq2, eq3}, {pc, ab, LM}]\)}], "Input",
  CellLabel->"In[22]:="],

Cell["\<\
So we see that the profit will be maximized if the price per computer is $935 \
/ month and the advertising budget is $100000 / month. This agrees well with \
our guess from above. The profit would be increased by $211250/month (as \
shown below).\
\>", "Text"],

Cell[BoxData[{
    \(Profit[935, 100000]\), "\[IndentingNewLine]", 
    \(Profit[935, 100000] - Profit[950, 50000]\)}], "Input",
  CellLabel->"In[27]:="],

Cell[CellGroupData[{

Cell["Lagrange Multipliers and Shadow Prices", "Subsubsection"],

Cell[TextData[{
  "We can use our knowledge of Lagrange multiplier and shadow prices to \
convince management that they should raise the advertising budget above \
$100000/month. The Lagrange multiplier we found was 37/10, and that can be \
interpreted as the rate of change in the maximum profit as the constraint \
(here, the upper limit on the ad budget) is relaxed. Our Lagrange multiplier \
tells us that if we increase the ad budget $10/month over $100 000 /month, \
then the profits will increase by $37/month. As I am not a trusting soul, I \
will repeat the calculation (which is very easy in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "!) to verify this."
}], "Text"],

Cell[BoxData[{
    \(\(g[pc_, ab_]\  = \ ab;\)\), "\[IndentingNewLine]", 
    \(\(eq1\  = \ 
        D[Profit[pc, ab], pc]\  \[Equal] \ 
          LM\ D[g[pc, ab], pc];\)\), "\[IndentingNewLine]", 
    \(\(eq2\  = \ 
        D[Profit[pc, ab], ab]\  \[Equal] \ 
          LM\ D[g[pc, ab], ab];\)\), "\[IndentingNewLine]", 
    \(\(eq3\  = \ g[pc, ab] \[Equal] 100010;\)\), "\[IndentingNewLine]", 
    \(Solve[{eq1, eq2, eq3}, {pc, ab, LM}]\)}], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(N[Profit[467501/500, 100010] - Profit[935, 100000]\ ]\)], "Input",
  CellLabel->"In[34]:="],

Cell["\<\
And we see that indeed, increasing the ad budget to $100010/month would \
result in an increase in profits of $37/month. It is an increase, but not a \
very large one!\
\>", "Text"],

Cell[TextData[{
  "The key word in this analysis is",
  StyleBox[" relaxed",
    FontSlant->"Italic"],
  ", and that means that these extensions are only true when we are changing \
the value of the constraint slightly. Obviously, the company cannot \
arbitrarily increase the advertising budget, nor would they want to--other \
factors would undoubtedly come into play. However, if they are happy with the \
level of detail contained in this model, then they may wish to consider \
increasing the ad budget over the $100000/month limit."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sensitivity Analysis: The Management's Ceiling on the Advertising Budget\
\>", "Subsubsection"],

Cell["\<\
The last thing we need to consider is sensitivity analysis. In fact, that has \
already been done in one sense. We know the sensitivity of the profit to the \
advertising budget constraint is related to the Lagrange multiplier, 37/10. \
This allowed us to make our statements regarding the shadow price above. \
However, let's verify that that is actually true. This will also show how we \
can check sensitivity to the constraint. 

What we do is change the constraint $100 000/month to a variable, \[Alpha], \
and then solve the problem for the optimal price per computer and the optimal \
advertising budget.\
\>", "Text"],

Cell[BoxData[{
    \(\(nc\  = \ 10000;\)\), "\[IndentingNewLine]", 
    \(\(mc\  = \ 700;\)\), "\[IndentingNewLine]", 
    \(\(wp\  = 950;\)\), "\[IndentingNewLine]", 
    \(\(pr\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(prsi\  = \ 50/100;\)\), "\[IndentingNewLine]", 
    \(\(abi\  = \ 10000;\)\), "\[IndentingNewLine]", 
    \(\(abisi\  = \ 200;\)\), "\[IndentingNewLine]", 
    \(\(cab\  = \ 50000;\)\), "\[IndentingNewLine]", 
    \(\(n = 
        nc*\((1 + \((wp - pc)\)/pr*prsi)\) + \((ab - cab)\)/abi*
            abisi;\)\), "\[IndentingNewLine]", 
    \(\(Profit[pc_, ab_]\  = \ 
        Simplify[n*\((pc - mc)\) - ab];\)\), "\[IndentingNewLine]", 
    \(\(g[pc_, ab_]\  = \ ab;\)\), "\[IndentingNewLine]", 
    \(\(eq1\  = \ 
        D[Profit[pc, ab], pc]\  \[Equal] \ 
          LM\ D[g[pc, ab], pc];\)\), "\[IndentingNewLine]", 
    \(\(eq2\  = \ 
        D[Profit[pc, ab], ab]\  \[Equal] \ 
          LM\ D[g[pc, ab], ab];\)\), "\[IndentingNewLine]", 
    \(\(eq3\  = \ g[pc, ab] \[Equal] \[Alpha];\)\), "\[IndentingNewLine]", 
    \(Solve[{eq1, eq2, eq3}, {pc, ab, LM}]\)}], "Input",
  CellLabel->"In[35]:="],

Cell["\<\
Now, we can define the optimal price per computer, and optimal advertising \
price, in terms of \[Alpha], which is the upper limit for the advertising \
budget that is imposed by management.\
\>", "Text"],

Cell[BoxData[{
    \(\(opc\  = \ \(4575000 + \[Alpha]\)\/5000;\)\), "\[IndentingNewLine]", 
    \(\(oab\  = \ \[Alpha];\)\), "\[IndentingNewLine]", 
    \(D[Profit[opc, oab], \[Alpha]]\  /. \ \[Alpha] \[Rule] 
        100000\), "\[IndentingNewLine]", 
    \(\(sensP[\[Alpha]_]\  = \ 
        D[Profit[opc, oab], \[Alpha]]\ \[Alpha]\ /
            Profit[opc, oab];\)\), "\[IndentingNewLine]", 
    \(N[sensP[100000]]\)}], "Input",
  CellLabel->"In[50]:="],

Cell["\<\
Notice that the derivative of the profit with respect to the variable \
advertising budget evaluated where the advertising budget is $100000/month is \
the same as the Lagrange multiplier we found above. This is neato! The \
sensitivity is 0.14, which is about 3/20, which means a 20% increase in the \
ceiling on the advertising budget would produce a 3% increase in the profits. \
Again, I am mistrustful, so let's work it out. Below, I increase \[Alpha] \
from 100000 to 100000 * 1.2, and calculate the optimal profit.\
\>", "Text"],

Cell[BoxData[{
    \(\(nc\  = \ 10000;\)\), "\[IndentingNewLine]", 
    \(\(mc\  = \ 700;\)\), "\[IndentingNewLine]", 
    \(\(wp\  = 950;\)\), "\[IndentingNewLine]", 
    \(\(pr\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(prsi\  = \ 50/100;\)\), "\[IndentingNewLine]", 
    \(\(abi\  = \ 10000;\)\), "\[IndentingNewLine]", 
    \(\(abisi\  = \ 200;\)\), "\[IndentingNewLine]", 
    \(\(cab\  = \ 50000;\)\), "\[IndentingNewLine]", 
    \(\(n = \(n = 
          nc*\((1 + \((wp - pc)\)/pr*prsi)\) + \((ab - cab)\)/abi*
              abisi\);\)\), "\[IndentingNewLine]", 
    \(\(Profit[pc_, ab_]\  = \ 
        Simplify[n*\((pc - mc)\) - ab];\)\), "\[IndentingNewLine]", 
    \(\(g[pc_, ab_]\  = \ ab;\)\), "\[IndentingNewLine]", 
    \(\(eq1\  = \ 
        D[Profit[pc, ab], pc]\  \[Equal] \ 
          LM\ D[g[pc, ab], pc];\)\), "\[IndentingNewLine]", 
    \(\(eq2\  = \ 
        D[Profit[pc, ab], ab]\  \[Equal] \ 
          LM\ D[g[pc, ab], ab];\)\), "\[IndentingNewLine]", 
    \(\(eq3\  = \ g[pc, ab] \[Equal] 100000*1.2;\)\), "\[IndentingNewLine]", 
    \(Solve[{eq1, eq2, eq3}, {pc, ab, LM}]\)}], "Input",
  CellLabel->"In[55]:="],

Cell["\<\
If we calculate the percentage increase in profits, we see that it is about \
3%. All is well.\
\>", "Text"],

Cell[BoxData[
    \(N[\((Profit[939, 120000] - Profit[935, 100000])\)/
        Profit[935, 100000]]\)], "Input",
  CellLabel->"In[70]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sensitivity Analysis: Percentage Increase in Sales When Price Reduced $100\
\>", "Subsubsection"],

Cell[TextData[{
  "Let's do another sensitivity analysis. Personally, I think that 50% number \
is pretty high, and possibly wrong, for the percentage increase in sales when \
prices are dropped by $100. I have to believe what my marketing gurus tell \
me, but I want to see how susceptible the optimal profits are to that number. \
I will proceed by setting the 50% to a variable, and solving the problem in \
terms of that variable. Here we go! (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " makes these sorts of checks very easy to perform--the work in solving a \
problem is in setting it up, once it is set up it is almost a shame to stop \
working on it!)"
}], "Text"],

Cell[BoxData[{
    \(\(nc\  = \ 10000;\)\), "\[IndentingNewLine]", 
    \(\(mc\  = \ 700;\)\), "\[IndentingNewLine]", 
    \(\(wp\  = 950;\)\), "\[IndentingNewLine]", 
    \(\(pr\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(prsi\  = \ \[Alpha]/100;\)\), "\[IndentingNewLine]", 
    \(\(abi\  = \ 10000;\)\), "\[IndentingNewLine]", 
    \(\(abisi\  = \ 200;\)\), "\[IndentingNewLine]", 
    \(\(cab\  = \ 50000;\)\), "\[IndentingNewLine]", 
    \(\(n = \(n = 
          nc*\((1 + \((wp - pc)\)/pr*prsi)\) + \((ab - cab)\)/abi*
              abisi\);\)\), "\[IndentingNewLine]", 
    \(\(Profit[pc_, ab_]\  = \ 
        Simplify[n*\((pc - mc)\) - ab];\)\), "\[IndentingNewLine]", 
    \(\(g[pc_, ab_]\  = \ ab;\)\), "\[IndentingNewLine]", 
    \(\(eq1\  = \ 
        D[Profit[pc, ab], pc]\  \[Equal] \ 
          LM\ D[g[pc, ab], pc];\)\), "\[IndentingNewLine]", 
    \(\(eq2\  = \ 
        D[Profit[pc, ab], ab]\  \[Equal] \ 
          LM\ D[g[pc, ab], ab];\)\), "\[IndentingNewLine]", 
    \(\(eq3\  = \ g[pc, ab] \[Equal] 100000;\)\), "\[IndentingNewLine]", 
    \(Solve[{eq1, eq2, eq3}, {pc, ab, LM}]\)}], "Input",
  CellLabel->"In[71]:="],

Cell["\<\
Not surprisingly, the optimal advertising budget remains at $100000/month, \
and is independent of \[Alpha]. Now, we can define the optimal price per \
computer, and optimal advertising price, in terms of \[Alpha]%, which in this \
case is the percentage that sales increase when the price of the computer is \
reduced $100. \
\>", "Text"],

Cell[BoxData[{
    \(\(opc\  = \ \(275\ \((20 + 3\ \[Alpha])\)\)\/\[Alpha];\)\), "\
\[IndentingNewLine]", 
    \(\(oab\  = \ 100000;\)\), "\[IndentingNewLine]", 
    \(\(sensP[\[Alpha]_]\  = \ 
        D[Profit[opc, oab], \[Alpha]]\ \[Alpha]\ /
            Profit[opc, oab];\)\), "\[IndentingNewLine]", 
    \(\(sensopc[\[Alpha]_]\  = \ 
        D[opc, \[Alpha]]\ \[Alpha]\ /opc;\)\), "\[IndentingNewLine]", 
    \(\(sensoab[\[Alpha]_]\  = \ 
        D[oab, \[Alpha]]\ \[Alpha]\ /oab;\)\), "\[IndentingNewLine]", 
    \(N[sensP[50]]\), "\[IndentingNewLine]", 
    \(N[sensopc[50]]\), "\[IndentingNewLine]", 
    \(N[sensoab[50]]\)}], "Input",
  CellLabel->"In[86]:="],

Cell[TextData[{
  "The interesting number above is the sensitivity of the optimal price per \
computer to \[Alpha]. ",
  Cell[BoxData[
      \(TraditionalForm\`\(-0.11~\ \(-1\)\)/10\)]],
  ", so every 10% increase in the percentage that sales increase above 50% \
when the price of the computer is reduced $100 will result in a 1% decrease \
in the optimal price of the computers. This means if sales increased only 45% \
for a $100 reduction in price, the optimal price to sell the computers at \
would be $925.65. This is not a big difference for the original estimate (50% \
and the optimal selling price should be $935), so I believe that the company \
would be wise to lower their prices, and up their advertising budget."
}], "Text"],

Cell[BoxData[
    \(Plot[{sensP[\[Alpha]], sensopc[\[Alpha]]}, {\[Alpha], 0, 100}, 
      PlotStyle \[Rule] {{Hue[1], Dashing[{0.05, 0.05}]}, {Hue[3/4], 
            Dashing[{1, 0}]}}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<\[Alpha]\>", "\<Sensitivities\>"}]\)], "Input",
  CellLabel->"In[94]:="],

Cell["\<\
The solid purple line is the sensitivity of the optimal price of the \
computers to \[Alpha], and the dashed red line is the sensitivity of the \
maximum profits to \[Alpha]. Notice that the sensitivity of the maximum \
profits to \[Alpha] is negative for \[Alpha]% less than about 40%. This means \
that the optimal profits will be greater than as things stand now, but not as \
large as they could be if we had a higher percentage of sales increase for a \
$100 decrease in the price of the computer. 

Remember, my original concern was with the profits, and a plot of the profits \
as a function of \[Alpha] will easily show that you will generate increased \
profits for all \[Alpha], and also illuminate what the change negative \
sensitivity means:\
\>", "Text"],

Cell[BoxData[
    \(Plot[{Profit[opc, oab], Profit[950, 50000]}, {\[Alpha], 0, 100}, 
      PlotRange \[Rule] {2000000, 4000000}, Frame \[Rule] True, \ 
      FrameLabel \[Rule] {"\<\[Alpha]\>", "\<Maximum Profits\>"}]\)], "Input",\

  CellLabel->"In[98]:="],

Cell["\<\
Things look good--you can perform other sensitivity analysis if you desire.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{692, 617},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "ArticleModern.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 47, 0, 63, "Section"],
Cell[1777, 54, 344, 11, 27, "Text"],
Cell[2124, 67, 747, 13, 141, "Text"],

Cell[CellGroupData[{
Cell[2896, 84, 37, 0, 43, "Subsubsection"],
Cell[2936, 86, 1789, 38, 327, "Text"],
Cell[4728, 126, 1005, 17, 312, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5770, 148, 50, 0, 54, "Subsection"],
Cell[5823, 150, 141, 3, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6001, 158, 41, 0, 54, "Subsection"],
Cell[6045, 160, 187, 4, 46, "Text"],
Cell[6235, 166, 447, 9, 185, "Input"],
Cell[6685, 177, 368, 7, 84, "Text"],
Cell[7056, 186, 729, 16, 165, "Input"],
Cell[7788, 204, 146, 3, 27, "Text"],
Cell[7937, 209, 734, 15, 165, "Input"],
Cell[8674, 226, 404, 6, 65, "Text"],
Cell[9081, 234, 239, 5, 65, "Input"],
Cell[9323, 241, 58, 0, 27, "Text"],
Cell[9384, 243, 258, 5, 65, "Input"],
Cell[9645, 250, 179, 4, 46, "Text"],
Cell[9827, 256, 766, 20, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10630, 281, 61, 0, 54, "Subsection"],
Cell[10694, 283, 253, 4, 46, "Text"],
Cell[10950, 289, 151, 4, 45, "Input"],
Cell[11104, 295, 80, 2, 45, "Input"],
Cell[11187, 299, 863, 17, 103, "Text"],
Cell[12053, 318, 477, 10, 125, "Input"],
Cell[12533, 330, 271, 5, 46, "Text"],
Cell[12807, 337, 153, 3, 65, "Input"],

Cell[CellGroupData[{
Cell[12985, 344, 63, 0, 43, "Subsubsection"],
Cell[13051, 346, 691, 12, 103, "Text"],
Cell[13745, 360, 477, 10, 125, "Input"],
Cell[14225, 372, 111, 2, 45, "Input"],
Cell[14339, 376, 191, 4, 46, "Text"],
Cell[14533, 382, 550, 10, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15120, 397, 105, 2, 43, "Subsubsection"],
Cell[15228, 401, 635, 11, 141, "Text"],
Cell[15866, 414, 1128, 23, 325, "Input"],
Cell[16997, 439, 214, 4, 46, "Text"],
Cell[17214, 445, 455, 9, 138, "Input"],
Cell[17672, 456, 545, 8, 84, "Text"],
Cell[18220, 466, 1142, 23, 325, "Input"],
Cell[19365, 491, 118, 3, 27, "Text"],
Cell[19486, 496, 137, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19660, 504, 107, 2, 43, "Subsubsection"],
Cell[19770, 508, 687, 12, 103, "Text"],
Cell[20460, 522, 1144, 23, 325, "Input"],
Cell[21607, 547, 349, 6, 65, "Text"],
Cell[21959, 555, 667, 14, 198, "Input"],
Cell[22629, 571, 739, 12, 103, "Text"],
Cell[23371, 585, 307, 5, 85, "Input"],
Cell[23681, 592, 778, 13, 141, "Text"],
Cell[24462, 607, 258, 5, 85, "Input"],
Cell[24723, 614, 99, 2, 27, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

